package Data::Object::Func::Code;

use Data::Object 'Class';

extends 'Data::Object::Func';

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Code

=cut

=head1 ABSTRACT

Functions for CodeRefs

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Code;

=cut

=head1 DESCRIPTION

Data::Object::Func::Code is an abstract base class for function classes in the
Data::Object::Func::Code space.

=cut
